##
##  pari.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major 2.17
%define       V_minor 1
%define       V_perl  2.03052201

#   package information
Name:         pari
Summary:      GP/PARI Number-Theory Library
URL:          http://pari.math.u-bordeaux.fr/
Vendor:       Henri Cohen et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Algorithm
License:      GPL
Version:      %{V_major}.%{V_minor}
Release:      20241224

#   package options
%option       with_perl  no

#   list of sources
Source0:      http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%{version}.tar.gz
Source1:      http://www.cpan.org/modules/by-module/Math/Math-Pari-%{V_perl}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, perl
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  gmp, readline, ncurses
PreReq:       gmp, readline, ncurses
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    PARI-GP is a software package for computer-aided number theory.
    It consists of the C library libpari and of the programmable
    interactive gp(1) calculator. While you can write your own
    libpari-based programs, many people just start up a gp(1) session,
    or have gp(1) execute their scripts.

%track
    prog pari = {
        version   = %{version}
        url       = http://pari.math.u-bordeaux.fr/download.html
        regex     = pari-(\d+\.\d+\.\d+)\.(tgz|tar\.gz)
    }
    prog pari:Math-Pari = {
        version   = %{V_perl}
        url       = http://www.cpan.org/modules/by-module/Math/
        regex     = Math-Pari-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %setup -q -D -T -a 1
    chmod u+w Math-Pari-%{V_perl}/*
    %{l_shtool} subst \
        -e 's;^\(install:.*\) install-doc \(.*\);\1 \2;' \
        config/Makefile.SH
    %{l_shtool} subst \
        -e 's;}; double y=log2(10)};' \
        config/has_exp2.c

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./Configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man/man1 \
        --datadir=%{l_prefix}/share/pari/galdata \
        --with-gmp=%{l_prefix} \
        --with-readline=%{l_prefix} \
        --with-ncurses=%{l_prefix} \
        --static
    %{l_make} %{l_mflags -O} gp
%if "%{with_perl}" == "yes"
    ( cd `./config/objdir`
      %{l_make} %{l_mflags -O} libpari.a
    ) || exit $?
    %{l_prefix}/bin/perl-openpkg prepare
    paridir=".."
    parihdr="-I$paridir/`./config/objdir`"
    parilib="-L$paridir/`./config/objdir` -lpari %{l_ldflags} -lgmp"
    %{l_prefix}/bin/perl-openpkg \
        -d Math-Pari-%{V_perl} \
        --args "paridir=\"$paridir\"" \
        --args "pariincludes=\"$parihdr\"" \
        --args "parilib=\"$parilib\"" \
        configure build
%endif

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/gp
    mv $RPM_BUILD_ROOT%{l_prefix}/bin/gp-%{V_major} \
       $RPM_BUILD_ROOT%{l_prefix}/bin/gp
    rm -f $RPM_BUILD_ROOT%{l_prefix}/man/man1/gp.1
    mv $RPM_BUILD_ROOT%{l_prefix}/man/man1/gp-%{V_major}.1 \
       $RPM_BUILD_ROOT%{l_prefix}/man/man1/gp.1
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/tex2mail
    rm -f $RPM_BUILD_ROOT%{l_prefix}/man/man1/tex2mail.1
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d Math-Pari-%{V_perl} install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

